@@ -27,7 +27,6 @@
 #include "modules/rtp_rtcp/source/rtp_packet_to_send.h"
 #include "modules/rtp_rtcp/source/rtp_sequence_number_map.h"
 #include "modules/rtp_rtcp/source/video_fec_generator.h"
-#include "rtc_base/constructor_magic.h"
 #include "system_wrappers/include/ntp_time.h"
 
 namespace webrtc {
@@ -47,6 +46,9 @@ class RtpRtcpInterface : public RtcpFeedbackSenderInterface {
     Configuration() = default;
     Configuration(Configuration&& rhs) = default;
 
+    Configuration(const Configuration&) = delete;
+    Configuration& operator=(const Configuration&) = delete;
+
     // True for a audio version of the RTP/RTCP module object false will create
     // a video version.
     bool audio = false;
@@ -145,9 +147,6 @@ class RtpRtcpInterface : public RtcpFeedbackSenderInterface {
     // Estimate RTT as non-sender as described in
     // https://tools.ietf.org/html/rfc3611#section-4.4 and #section-4.5
     bool non_sender_rtt_measurement = false;
-
-   private:
-    RTC_DISALLOW_COPY_AND_ASSIGN(Configuration);
   };
 
   // Stats for RTCP sender reports (SR) for a specific SSRC.
